Assert function expects specific parameter names
Source:R/assert_functions.R
assert_function_expects.RdAssert that a function signature includes required set of parameter names in its
formal argument list, regardless of whether those parameters have default
values. The ... argument is ignored.
Usage
assert_function_expects(
x,
required,
msg = NULL,
call = rlang::caller_env(),
arg_name = NULL
)Arguments
- x
a function to check for required parameter names
- required
a character vector of parameter names that must appear in the function signature (order does not matter)
- msg
The error message thrown if the assertion fails (string)
- call
Only relevant when pooling assertions into multi-assertion helper functions. See cli_abort for details.
- arg_name
Advanced use only. Name of the argument passed (default: NULL, will automatically extract arg_name).