Check that a single numeric value is finite (not NA, NaN, Inf, or -Inf).
For vectorized version see assert_all_finite().
Usage
assert_finite(x, msg = NULL, call = rlang::caller_env(), arg_name = NULL)Arguments
- x
An object
- msg
The error message thrown if the assertion fails (string)
- call
Only relevant when pooling assertions into multi-assertion helper functions. See cli_abort for details.
- arg_name
Advanced use only. Name of the argument passed (default: NULL, will automatically extract arg_name).
Examples
try({
assert_finite(1) # Passes
assert_finite(Inf) # Throws error
})
#> Error in eval(expr, envir) : Inf must be finite.